Page 115 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 115

Home

    of the State, which instituted a "National Church" of its
    own and invited United States sects to replace them; and
    "God" was eliminated from oaths and textbooks and civil
    formalities.

    When the Mexican people rose up against Juarez, and
    elected a new government, the United States broke off
    diplomatic relations with the new government and
    supported Juarez to the point of military action. This
    began a policy carried out by the United States
    government throughout the 20th century. The agents that
    have carried out such policies have all worked toward a
    common long-range goal, and have generally had ties to
    a center of power that we have described as "Modern
    Day Babylon."

    By 1876, the accession of Porfirio Diaz to president
    tempered the States' war against the Church and by the
    end of the Diaz period the Church was conducting some
    2,000 free schools and colleges, and a new network of
    hospitals and institutions. These were maintained by
    clergy and sisterhoods dependent entirely upon charity.
    This continued up to the presidency of Huerta when
    according to Kenny:

    .. President Wilson supported with army and navy
    the worst scoundrels that ever raped and pillaged
    Mexico; whence issued the orgy of anarchy and tyranny
    that culminated in Calles.”

    110

    The Secret Side of History